@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000012';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000013';
 use Moose;
 use namespace::autoclean;
 
@@ -104,10 +104,12 @@ sub configure {
         'AutoPrereqs',
         'CheckChangesHasContent',
         'ConfirmRelease',
+        'MakeMaker',    # needs to precede InstallGuide
         'CPANFile',
         'ContributorsFile',
         'InstallGuide',
         'MetaJSON',
+        'MetaYAML',
         'License',
         [ 'CopyFilesFromBuild' => { copy => \@copy } ],
         'ExecDir',
@@ -133,13 +135,11 @@ sub configure {
         'Git::Contributors',
         'Git::Tag',
         'Git::Push',
-        'MakeMaker',
         'Manifest',
         'ManifestSkip',
         'MAXMIND::TidyAll',
         [ 'MetaNoIndex' => { directory => [ 'examples', 't', 'xt' ] } ],
         'MetaResources',
-        'MetaYAML',
         'MetaConfig',
         'MinimumPerl',
         'PkgVersion',
@@ -205,7 +205,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000012
+version 0.000013
 
 =head2 configure
 
